@@ -1,12 +1,18 @@
 from django.db import models
 # Create your models here.
 
-import caching.base
+import caching
+
+class Orthography(models.Model):
+    word = models.CharField(max_length = 250,unique=True)
+
+    def __unicode__(self):
+        return self.word
 
 class Trigram(caching.base.CachingMixin, models.Model):
-    word = models.CharField(max_length=250)
-    word_i_minus_one = models.CharField(max_length=250)
-    word_i_minus_two = models.CharField(max_length=250)
+    word = models.ForeignKey(Orthography,related_name='word')
+    word_i_minus_one = models.ForeignKey(Orthography,related_name='word_i_minus_one')
+    word_i_minus_two = models.ForeignKey(Orthography,related_name='word_i_minus_one')
     count = models.IntegerField()
 
     objects = caching.base.CachingManager()
